@@ -5,7 +5,7 @@
 #' 
 #' @description A unique display of hillslope position probability.
 #' 
-#' @param x \code{data.frame} as created by \code{soilDB::fetchOSD(..., extended=TRUE)}, see details
+#' @param x `data.frame` as created by `soilDB::fetchOSD(..., extended = TRUE)`
 #' 
 #' @param s an optional soil series name, highlighted in the figure
 #' 
@@ -15,18 +15,20 @@
 #' 
 #' @param cols vector of colors
 #' 
+#' @param \dots additional arguments to `[iterateHydOrder]`: `target = 0.9, maxIter = 20, j.amount = 0.05, verbose = FALSE`
 #' 
 #' @return
 #' A `list` with the following elements:
 #'    * `fig`: lattice object (the figure)
 #'    * `order`: 1D ordering from `cluster::diana`
-#'    * `clust`: clustering object returned by `cluster::diana`
+#'    * `clust`: `hclust` object
+#'    * `match.rate`: fraction of series matching target hydrologic ordering, after clustering + rotation 
 #' 
 #' @details See the \href{http://ncss-tech.github.io/AQP/soilDB/soil-series-query-functions.html}{Soil Series Query Functions} tutorial for more information.
 #' 
 #' @author D.E. Beaudette
 #' 
-vizHillslopePosition <- function(x, s = NULL, annotations = TRUE, annotation.cex = 0.75, cols = c("#2B83BA", "#ABDDA4", "#FFFFBF", "#FDAE61", "#D7191C")) {
+vizHillslopePosition <- function(x, s = NULL, annotations = TRUE, annotation.cex = 0.75, cols = c("#2B83BA", "#ABDDA4", "#FFFFBF", "#FDAE61", "#D7191C"), ...) {
   
   # sanity checks on input
   if(!inherits(x, 'data.frame')) {
@@ -69,21 +71,18 @@ vizHillslopePosition <- function(x, s = NULL, annotations = TRUE, annotation.cex
   # cols <- rev(brewer.pal(5, 'Spectral'))
   
   # setup plot styling
-  tps <- list(superpose.polygon=list(col=cols, lwd=2, lend=2))
+  tps <- list(superpose.polygon = list(col = cols, lwd = 2, lend = 2))
   
   ## all of the fancy ordering + dendrogram require > 1 series
   if(n.series > 1) {
-    # re-order labels based on sorting of proportions: "hydrologic" ordering
-    hyd.order <- order(rowSums(sweep(x[, -1], 2, STATS=c(-4, -2, 0.1, 2, 4), FUN = '*')), decreasing = TRUE)
     
-    # cluster proportions: results are not in "hydrologic" order, but close
-    x.d <- as.hclust(diana(daisy(x[, -1])))
-    
-    # rotate clustering according to hydrologic ordering
-    x.d.hydro <- dendextend::rotate(x.d, order = x$series[hyd.order]) # dendextend approach
+    # iteratively apply hydrologic ordering, 
+    .res <- iterateHydOrder(x, g = 'hillpos', ...)
+    x.d.hydro <- .res$clust
+    .match.rate <- .res$match.rate
     
     # re-order labels levels based on clustering
-    x.long$series <- factor(x.long$series, levels=x.long$series[x.d.hydro$order])
+    x.long$series <- factor(x.long$series, levels = x$series[x.d.hydro$order])
     
     # dendrogram synced to bars
     leg <- list(
@@ -91,8 +90,8 @@ vizHillslopePosition <- function(x, s = NULL, annotations = TRUE, annotation.cex
         fun = latticeExtra::dendrogramGrob,
         args = list(
           x = as.dendrogram(x.d.hydro), 
-          side="right", 
-          size=10)
+          side = "right", 
+          size = 10)
       )
     )
     
@@ -105,6 +104,7 @@ vizHillslopePosition <- function(x, s = NULL, annotations = TRUE, annotation.cex
     
     # simulate output from clustering
     x.d.hydro <- list(order = 1L)
+    .match.rate <- NA
   }
   
   
@@ -181,8 +181,14 @@ vizHillslopePosition <- function(x, s = NULL, annotations = TRUE, annotation.cex
   # embed styling
   pp <- update(pp, par.settings = tps)
   
-  # figure, ordering, clustering object
-  res <- list(fig = pp, order = x.d.hydro$order, clust = x.d.hydro)
+  # re-pack results
+  res <- list(
+    fig = pp, 
+    order = x.d.hydro$order, 
+    clust = x.d.hydro, 
+    match.rate = .match.rate
+  ) 
+  
   return(res)
 }
 
